lavalink_plugins library

A library that extends the base lavalink package by providing bindings to some external lavalink plugins.

Classes

Chapter
ChaptersLoaded
Fired when a new chapter starts.
ChapterStarted
Fired when a new chapter starts.
LavaLyricsPlugin
LyricLine
Lyrics
LyricsFoundEvent
Fired when lyrics are found for a track and about to be sent to the client.
LyricsLineEvent
Fired when a new lyrics line is reached for a track.
LyricsNotFoundEvent
Fired when no lyrics were found for a track.
Segment
A segment of the timespan of the sponsorblock data.
SegmentSkipped
An event that happens when a segment has been skipped.
SegmentsLoaded
Fired when the segments for a track are loaded.
SponsorblockPlugin
A plugin for the SponsorBlock lavalink plugin.