LavaLyricsPlugin class
Properties
client
→ LavalinkClient
A reference to this client.
final inherited
handledEvents
→ Map <String , LavalinkExternalPluginEventHandler >
A list of all handled events by this plugins.
final
hashCode
→ int
The hash code for this object.
no setter inherited
name
→ String
The name of this plugin.
no setter
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
getCurrentPlayingTrackLyrics (String guildId , {bool shouldSkipTrackSource = false })
→ Future <Lyrics ? >
Gets the lyrics of the current playing track. By default, it will try to fetch the lyrics from where the track is sourced from.
E.g. if the track is from Deezer it will try to fetch the lyrics from Deezer.
You can disable this behavior by setting shouldSkipTrackSource to true.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeToLiveLyrics (String guildId , {bool shouldSkipTrackSource = false })
→ Future <void >
Subscribes to live lyrics for a given player.
toString ()
→ String
A string representation of this object.
inherited
unsubscribeFromLiveLyrics (String guildId )
→ Future <void >
Unsubscribes from live lyrics for a given player.